@@ -1,5 +1,7 @@
 """
-Main interface for lex-runtime service client
+Type annotations for lex-runtime service client.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html)
 
 Usage::
 
@@ -53,7 +55,8 @@ class Exceptions:
 
 class LexRuntimeServiceClient:
     """
-    [LexRuntimeService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.34/reference/services/lex-runtime.html#LexRuntimeService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html)
     """
 
     meta: ClientMeta
@@ -61,14 +64,16 @@ class LexRuntimeServiceClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.34/reference/services/lex-runtime.html#LexRuntimeService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#can-paginate)
         """
 
     def delete_session(
         self, botName: str, botAlias: str, userId: str
     ) -> DeleteSessionResponseTypeDef:
         """
-        [Client.delete_session documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.34/reference/services/lex-runtime.html#LexRuntimeService.Client.delete_session)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client.delete_session)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#delete-session)
         """
 
     def generate_presigned_url(
@@ -79,14 +84,16 @@ class LexRuntimeServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.34/reference/services/lex-runtime.html#LexRuntimeService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#generate-presigned-url)
         """
 
     def get_session(
         self, botName: str, botAlias: str, userId: str, checkpointLabelFilter: str = None
     ) -> GetSessionResponseTypeDef:
         """
-        [Client.get_session documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.34/reference/services/lex-runtime.html#LexRuntimeService.Client.get_session)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client.get_session)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#get-session)
         """
 
     def post_content(
@@ -102,7 +109,8 @@ class LexRuntimeServiceClient:
         activeContexts: str = None,
     ) -> PostContentResponseTypeDef:
         """
-        [Client.post_content documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.34/reference/services/lex-runtime.html#LexRuntimeService.Client.post_content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client.post_content)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#post-content)
         """
 
     def post_text(
@@ -116,7 +124,8 @@ class LexRuntimeServiceClient:
         activeContexts: List["ActiveContextTypeDef"] = None,
     ) -> PostTextResponseTypeDef:
         """
-        [Client.post_text documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.34/reference/services/lex-runtime.html#LexRuntimeService.Client.post_text)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client.post_text)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#post-text)
         """
 
     def put_session(
@@ -131,5 +140,6 @@ class LexRuntimeServiceClient:
         activeContexts: List["ActiveContextTypeDef"] = None,
     ) -> PutSessionResponseTypeDef:
         """
-        [Client.put_session documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.34/reference/services/lex-runtime.html#LexRuntimeService.Client.put_session)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client.put_session)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#put-session)
         """
